<?php

namespace Elementon\FilamentTheme;

use Filament\Contracts\Plugin;
use Filament\Enums\ThemeMode;
use Filament\Panel;
use Filament\Support\Colors\Color;
use Filament\FontProviders\LocalFontProvider;
use Filament\Support\Facades\FilamentAsset;
use Filament\Support\Assets\Css;

class ThemePlugin implements Plugin
{
    public static function make(): static
    {
        return app(static::class);
    }

    public function getId(): string
    {
        return 'elementon/filament-theme';
    }

    public function register(Panel $panel): void
    {
        $panel
            ->defaultThemeMode(ThemeMode::Light)
            ->font(
                'Magdelin Alt',
                 provider: LocalFontProvider::class,
            )
            ->colors([
                'primary' => '#EE4266',
                'gray' => [
                    '50' => '#F6F8FA',
                    '100' => "#F6F8FA",
                    '200' => "#ECF0F4",
                    '300' => "#D8E0E8",
                    '400' => "#9AA2C1",
                    '500' => "#8088B3",
                    '600' => "#656EA4",
                    '700' => "#40476D",
                    '800' => "#333957",
                    '900' => "#2E324D",
                    '950' => "#2E324D",
                ],
                'danger' => Color::Red,
                'info' => Color::Blue,
                'success' => Color::Green,
                'warning' => Color::Orange,
            ]);
    }

    public function boot(Panel $panel): void
    {
        FilamentAsset::register([
            Css::make('elementon-filament-theme', asset('vendor/elementon/filament-theme/css/tweaks.css')),
        ]);
    }
}
